function param = simulate_prior(prior)
% SIMULATE_PRIOR Draw parameters of GDP solera model from prior distrib. 
% 
%   PARAM = SIMULATE_PRIOR(PRIOR) returns vector of parameters PARAM from
%   prior distribution PRIOR:
%     PRIOR is struct, see construct_prior.m.
%     PARAM is (N_c+2*N_c^2 + N_E+N_E^2 + N_I+N_I^2)x1, see vec_parameters.m.
% 
%   Version: 2023 Jul 12 - Tincho Almuzara - Matlab R2017b

% Recover dimensions and set function handles
N_c        = size(prior.S_X, 1);
symmetrize = @(A) (A + A')/2;

% Draw parameters of signal
Sigma_X = iwishrnd(prior.nu_X*prior.S_X, prior.nu_X);
beta_X  = mvnrnd(prior.m_X, symmetrize( kron(pinv(prior.P_X), Sigma_X) ))';
mu_X    = beta_X(1:N_c);
rho_X   = reshape(beta_X(N_c + (1:N_c^2)), [N_c, N_c]);

% Draw parameters of measurement error in GDP
Sigma_E = iwishrnd(prior.nu_E*prior.S_E, prior.nu_E);
rho_E   = mvnrnd(prior.m_E, symmetrize( kron(pinv(prior.P_E), Sigma_E) ))';

% Draw parameters of measurement error in GDI
Sigma_I = iwishrnd(prior.nu_I*prior.S_I, prior.nu_I);
rho_I   = mvnrnd(prior.m_I, symmetrize( kron(pinv(prior.P_I), Sigma_I) ))';

% Vectorize parameters
param = vec_parameter(mu_X, rho_X, Sigma_X, ...
                            rho_E, Sigma_E, ...
                            rho_I, Sigma_I);
                      
end