function [mu_T, lambda_T, sigma_T, rho_C, lambda_C, sigma_C, ...
          rho_E, lambda_E, sigma_E, rho_I, lambda_I, sigma_I] = map_parameter(param, dims)
% MAP_PARAMETER  Extract parameter array of GDP solera model into 
%   individual parameters.
% 
%   [...] = MAP_PARAMETER(PARAM, DIMS) returns arrays assuming individual
%   parameters vertically concatenated into PARAM with dimensions 
%   DIMS = [N_C, N_E, N_I].
%
%   Version: 2023 Jul 11 - Tincho Almuzara - Matlab R2017b

% Recover dimensions
N_c = dims(1);
N_E = dims(2);
N_I = dims(3);

% Create auxiliary index
n_param = [N_c, N_c, N_c, 2*N_c, 2*N_c, 2*N_c, ...
           N_E, N_E, N_E, N_I, N_I, N_I];
idx_temp = [cumsum([1, n_param(1:(end-1))], 2); cumsum(n_param, 2)];

% Map parameters
mu_T     = param(idx_temp(1,  1):idx_temp(2,  1), :);
lambda_T = param(idx_temp(1,  2):idx_temp(2,  2), :);
sigma_T  = param(idx_temp(1,  3):idx_temp(2,  3), :);
rho_C    = reshape(param(idx_temp(1,  4):idx_temp(2,  4), :), [N_c, 2]);
lambda_C = reshape(param(idx_temp(1,  5):idx_temp(2,  5), :), [N_c, 2]);
sigma_C  = reshape(param(idx_temp(1,  6):idx_temp(2,  6), :), [N_c, 2]);
rho_E    = param(idx_temp(1,  7):idx_temp(2,  7), :);
lambda_E = param(idx_temp(1,  8):idx_temp(2,  8), :);
sigma_E  = param(idx_temp(1,  9):idx_temp(2,  9), :);
rho_I    = param(idx_temp(1, 10):idx_temp(2, 10), :);
lambda_I = param(idx_temp(1, 11):idx_temp(2, 11), :);
sigma_I  = param(idx_temp(1, 12):idx_temp(2, 12), :);

end